@@ -38,14 +38,15 @@ id=NULL,start.time=0,max.time=NULL,offsets=0,Nit=50,detail=0,n.sim=500)
   else { stop("only right-censored or counting processes data") }
 
   if (sum(duplicated(time2[status==1]))>0) {
-    cat("Non unique survival times: break ties ! \n")
-    cat("Break ties yourself\n");
+    #cat("Non unique survival times: break ties ! \n")
+    # cat("Break ties yourself\n");
+    ties<-TRUE
     dtimes<-time2[status==1]
     index<-(1:length(time2))[status==1]
     ties<-duplicated(dtimes); nties<-sum(ties); index<-index[ties]
     dt<-diff(sort(time2)); dt<-min(dt[dt>0]); 
     time2[index]<-time2[index]+runif(nties,0,min(0.001,dt/2));
-  }
+  } else ties<-FALSE; 
 
   times<-unique(time2); 
   times <- c(start.time, times[times>start.time]); times <- sort(times)
